﻿#region Copyright © convivo GmbH
// ------------------------------------------------------------------------------------------------------------------------
// <copyright file="InvestigationOrderController.Validation.cs.cs" company="convivo GmbH">
//    Copyright © 2014 convivo GmbH
// </copyright>
// <creator name="convivo GmbH"/>
// ------------------------------------------------------------------------------------------------------------------------
#endregion

namespace Fruitmonitoring.Controllers.Common
{
    #region usings
    using System;
    using System.Linq;
    using System.Web.Mvc;

    using DevExpress.Data.Filtering;

    using Fruitmonitoring.Controllers.General;
    using Fruitmonitoring.Controllers.Interfaces;
    using Fruitmonitoring.Helper.HtmlExtensions.DropDownEditSelection;
    using Fruitmonitoring.Helper.Utility;
    using Fruitmonitoring.Helper.Validation;
    using Fruitmonitoring.Helper.Validation.Interfaces;
    using Fruitmonitoring.Infrastructure.Security;
    using Fruitmonitoring.Models;

    using Languages;
    using Languages.ModelData.SampleInvestigationOrder;
    using Languages.Pages.Common.InvestigationOrder;

    using Sample = Languages.ModelData.Sample.Sample;

    #endregion

    /// <summary>
    /// The investigation order controller.
    /// </summary>
    [CustomAuthorize(AppRole = FruitmonitoringRoles.SuperAdmin | FruitmonitoringRoles.Orderer)]
    public partial class InvestigationOrderController : BaseInvestigationOrderController, IDataManipulator<USP_Sample_Investigation_Sel_Result>
    {
        #region Properties

        #region Fields
        /// <summary>
        /// The helper.
        /// </summary>
        private readonly ISampleValidationHelper helper = new SampleValidationHelper();
        #endregion

        #endregion

        #region Public Methods and Operators
        /// <summary>
        /// do additional validation for temporary save here
        /// </summary>
        /// <param name="model">sample investigation model</param>
        /// <param name="retailerSelectionIds">The selected retailer ids.</param>
        /// <param name="accountId">The useres account id.</param>
        public void AdditionalTemporaryValidation(USP_Sample_Investigation_Sel_Result model, string[] retailerSelectionIds, Guid accountId)
        {
        }
        #endregion

        #region Methods
        /// <summary>
        /// Validate the given model.
        /// </summary>
        /// <param name="model">
        /// Model for validation.
        /// </param>
        /// <param name="viewData">
        /// ViewData contains additional information for validation.
        /// </param>
        /// <param name="validateForShortForm">
        /// FullValidation or not.
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool additionalDependencyValidation(USP_Sample_Investigation_Sel_Result model, ViewDataDictionary viewData, bool validateForShortForm = false)
        {
            return false;
        }

        /// <summary>
        /// Returns true if bioInstance depence on BioProductType_id is correct, otherwise ModelError is added.
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateBioInstance(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// returns true if brandtype depence on BrandType_id, PrivateBrand_Secured_id, Brand and retailer is correct, otherwise ModelError is added.
        /// If PrivateBrand_Secured_id is disallowed for given brandtypeid the value is set to default.
        /// </summary>
        /// <param name="model"></param>
        /// <param name="retailer"></param>
        /// <param name="isValid"></param>
        /// <returns></returns>
        private bool validateBrand(USP_Sample_Investigation_Sel_Result model, string[] retailer, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Returns true if at least one Certification Business is selected, otherwise ModelError is added.
        /// </summary>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateCertificationBusiness(bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Returns true if at least one product certification is selected, otherwise ModelError is added.
        /// </summary>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateCertificationProducts(bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Returns true if at least one quality seal certification is selected, otherwise ModelError is added.
        /// </summary>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateCertificationQualitySeals(bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Validate that the sampleStatus is "order edit"
        /// otherwise the order/sample can't be edited and ModelError is added.
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateFarmingType(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Returns isValid if at least one the three order types is true, otherwise returns false.
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateInvestigationOrderExamination(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Validates private brand.
        /// </summary>
        /// <param name="model">Investigation order model.</param>
        /// <param name="retailer">Selected retailers.</param>
        /// <param name="isValid">Current isValid state.</param>
        /// <returns>Rturns true, if private brand selection is valid. Otherwise false.</returns>
        private bool validatePrivateBrand(USP_Sample_Investigation_Sel_Result model, string[] retailer, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Returns true if Region depence on Retailer is correct, otherwise ModelError is added.
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="retailerIds">
        /// The retailer Ids.
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateRegion(USP_Sample_Investigation_Sel_Result model, string[] retailerIds, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Returns true if Retailer depence on CompanyClient_id is correct, otherwise ModelError is added.
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="retailers">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateRetailer(USP_Sample_Investigation_Sel_Result model, string[] retailers, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Validate that a retailer can only select themself.
        /// </summary>
        /// <param name="retailers">
        /// Current retailer selection.
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool ValidateRetailerSelection(string[] retailers, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Validate company factory is not false or "---" (default company).
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateSampleCompanyFactory(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Validate company laboratory is not false or "---" (default company).
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateSampleCompanyLaboratory(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Validate company producer
        /// producer is only required, if the company-client contains the companytype "producer"
        /// If its not required set defaultCompanyNone.
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateSampleCompanyProducer(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Validate company sender is not false or "---" (default company).
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateSampleCompanySender(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Validate company Supplier is not false or "---" (default company).
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="retailerCheckBoxArrayIds">
        /// The retailer Check Box Array Ids.
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateSampleCompanySupplier(USP_Sample_Investigation_Sel_Result model, string[] retailerCheckBoxArrayIds, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Returns true if SampleExaminationCount depence on SampleExamination_id is correct, otherwise a ModelError is added.
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateSampleExamination(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Removes SampleKindInfo when info is not necessary,
        /// returns true when SampleKind_id and SampleKindInfo together is correct, otherwise ModelError is added.
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateSampleKind(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Do server-side validation for SampleQuantity and SampleCount, at least one of them has to be specified.
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateSampleQuantityAndCount(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Validate samplerUser is not false or "---" (default User).
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateSampleSamplerUser(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Validate that the sampleStatus is "order edit"
        /// otherwise the order/sample can't be edited and ModelError is added.
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateSampleStatusOrderEdit(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// Returns true if Samplingdate is correct, otherwise ModelError is added.
        /// </summary>
        /// <param name="model">
        /// </param>
        /// <param name="isValid">
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private bool validateSamplingDateNotInFuture(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// validate processing status is not false or "---" (default processing status)
        /// </summary>
        /// <param name="model">The model</param>
        /// <param name="isValid">Is valid</param>
        /// <returns></returns>
        private bool validateProcessingStatus(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        /// <summary>
        /// validate intended use is not false or "---" (default intended use)
        /// </summary>
        /// <param name="model">The model</param>
        /// <param name="isValid">Is valid</param>
        /// <returns></returns>
        private bool validateIntendedUse(USP_Sample_Investigation_Sel_Result model, bool isValid)
        {
            return false;
        }

        #endregion
    }
}