﻿#region Copyright © convivo GmbH
// ------------------------------------------------------------------------------------------------------------------------
// <copyright file="Upload.cs.cs" company="convivo GmbH">
//    Copyright © 2014 convivo GmbH
// </copyright>
// <creator name="convivo GmbH"/>
// ------------------------------------------------------------------------------------------------------------------------
#endregion

namespace Fruitmonitoring.Helper.FileHelper
{
    #region usings
    using System;
    using System.Configuration;
    using System.IO;
    using System.Linq;
    using System.Web;

    using DevExpress.Web;

    using Fruitmonitoring.Helper.Sample;
    using Fruitmonitoring.Helper.Utility;
    using Fruitmonitoring.Models;

    using Languages.Components;

    #endregion

    /// <summary>
    /// The upload.
    /// </summary>
    public class Upload
    {
        #region Properties
        /// <summary>
        /// Set files validation settings.
        /// </summary>
        public UploadControlValidationSettings UploadControlValidationSettings
        {
            get
            {
                return new UploadControlValidationSettings()
                       {
                           AllowedFileExtensions = new[] { ".jpg", ".jpeg", ".gif", ".png", ".pdf", ".doc", ".docx", ".xls", ".xlsx" },
                           MaxFileSize = long.Parse(ConfigurationManager.AppSettings["MaxFileUploadSize"].ToString()) * 1024 * 1024,
                           MaxFileSizeErrorText = DocumentFileUploader.MaxFileSizeErrorText,
                           NotAllowedFileExtensionErrorText = DocumentFileUploader.NotAllowedFileExtensionErrorText,
                           GeneralErrorText = DocumentFileUploader.FileUploadGeneralError
                       };
            }

        }
        #endregion

        #region Public Methods and Operators
        /// <summary>
        /// This handler is called, after the file upload is complete.
        /// </summary>
        /// <param name="sender">
        /// Sender object.
        /// </param>
        /// <param name="e">
        /// Event object.
        /// </param>
        /// <param name="sampleId">
        /// Current sample id.
        /// </param>
        /// <param name="companyId">
        /// Current company id.
        /// </param>
        /// <param name="accountId">
        /// Current account id.
        /// </param>
        /// <param name="server">
        /// Current hhtpServer instance.
        /// </param>
        public static void FileUploadCompleteHandler(
            object sender,
            FileUploadCompleteEventArgs e,
            Guid? sampleId,
            Guid companyId,
            Guid accountId,
            HttpServerUtilityBase server)
        {
        }

        /// <summary>
        /// Save file from uploaded file to hdd and db.
        /// </summary>
        /// <param name="fileBytes">
        /// File data.
        /// </param>
        /// <param name="fileName">
        /// Filename with file-extension.
        /// </param>
        /// <param name="sampleId">
        /// File will apend to this sample.
        /// </param>
        /// <param name="companyId">
        /// Current users-company-id.
        /// </param>
        /// <param name="userId">
        /// Current users-userid.
        /// </param>
        /// <param name="server">
        /// Current hhtpServer instance.
        /// </param>
        /// <returns>
        /// New guid of saved file.
        /// </returns>
        public static Guid SaveFile(byte[] fileBytes, string fileName, Guid? sampleId, Guid companyId, Guid userId, HttpServerUtilityBase server)
        {
            return Guid.NewGuid();
        }
        #endregion

        #region Methods
        /// <summary>
        /// The check if common document exists in db.
        /// </summary>
        /// <param name="companyId">
        /// The company id.
        /// </param>
        /// <param name="fileName">
        /// The file name.
        /// </param>
        /// <param name="dbPath">
        /// The db path.
        /// </param>
        /// <param name="db">
        /// The db.
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private static bool checkIfCommonDocumentExistsInDb(Guid? companyId, string fileName, string dbPath, Entities db)
        {
            return false;
        }

        /// <summary>
        /// Check max 20 files,
        /// every company can upload up to 20 files per sample.
        /// </summary>
        /// <param name="companyId">
        /// The company Id.
        /// </param>
        /// <param name="db">
        /// The db.
        /// </param>
        /// <param name="sample">
        /// The sample.
        /// </param>
        /// <returns>
        /// The <see cref="bool"/>.
        /// </returns>
        private static bool maxFileUploadsReached(Guid companyId, Entities db, USP_Sample_Sel_Result sample)
        {
            return false;
        }

        /// <summary>
        /// The save file to db.
        /// </summary>
        /// <param name="newDocumentGuid">
        /// The new document guid.
        /// </param>
        /// <param name="sampleId">
        /// The sample id.
        /// </param>
        /// <param name="companyId">
        /// The company id.
        /// </param>
        /// <param name="fileName">
        /// The file name.
        /// </param>
        /// <param name="dbPath">
        /// The db path.
        /// </param>
        /// <param name="db">
        /// The db.
        /// </param>
        /// <param name="accountGuid">
        /// The users account id.
        /// </param>
        private static void saveFileToDb(Guid newDocumentGuid, Guid? sampleId, Guid companyId, string fileName, string dbPath, Entities db, Guid accountGuid)
        {
        }
        #endregion
    }
}