﻿#region Copyright © convivo GmbH
// ------------------------------------------------------------------------------------------------------------------------
// <copyright file="Culture.cs.cs" company="convivo GmbH">
//    Copyright © 2013 convivo GmbH
// </copyright>
// <creator name="convivo GmbH"/>
// ------------------------------------------------------------------------------------------------------------------------
#endregion

namespace Fruitmonitoring.Helper.HtmlExtensions.LanguageSwitcher
{
    /// <summary>
    /// This class represents some culture info to build the language switcher.
    /// </summary>
    public class Culture
    {
        #region Constructors and Destructors

        #region constructors
        /// <summary>
        /// Initializes a new instance of the <see cref="Culture"/> class.
        /// default constructor, which sets all values for an culture.
        /// </summary>
        /// <param name="cultureName">
        /// Short name of the culture (e.g. de-DE).
        /// </param>
        /// <param name="iconUrlOn">
        /// Url to the image of the coloured flag.
        /// </param>
        /// <param name="iconUrlOff">
        /// Url to the image of the gray flag.
        /// </param>
        /// <param name="altText">
        /// Alternativ text for the image.
        /// </param>
        /// <param name="title">
        /// Title text for the image.
        /// </param>
        public Culture(string cultureName, string iconUrlOn, string iconUrlOff, string altText = "", string title = "")
        {
            CultureName = cultureName;
            IconUrlOn = iconUrlOn;
            IconUrlOff = iconUrlOff;
            AltText = altText;
            Title = title;
        }
        #endregion

        #endregion

        #region variables
        /// <summary>
        /// Gets or sets the culture name.
        /// </summary>
        public string CultureName { get; set; }

        /// <summary>
        /// Gets or sets the icon url on.
        /// </summary>
        public string IconUrlOn { get; set; }

        /// <summary>
        /// Gets or sets the icon url off.
        /// </summary>
        public string IconUrlOff { get; set; }

        /// <summary>
        /// Gets or sets the alt text.
        /// </summary>
        public string AltText { get; set; }

        /// <summary>
        /// Gets or sets the title.
        /// </summary>
        public string Title { get; set; }
        #endregion
    }
}