﻿#region Copyright © convivo GmbH
// ------------------------------------------------------------------------------------------------------------------------
// <copyright file="DateHelper.cs.cs" company="convivo GmbH">
//    Copyright © 2013 convivo GmbH
// </copyright>
// <creator name="convivo GmbH"/>
// ------------------------------------------------------------------------------------------------------------------------
#endregion

namespace Fruitmonitoring.Helper.Utility
{
    #region usings
    using System;
    using System.Web;

    using Fruitmonitoring.Helper.Utility.Interfaces;

    #endregion

    /// <summary>
    /// The date helper.
    /// </summary>
    public class DateHelper : IDateHelper
    {
        #region Properties

        #region Static Fields
        /// <summary>
        /// The placeholderdate.
        /// </summary>
        public static DateTime PLACEHOLDERDATE = DateTime.MinValue;
        #endregion

        #endregion

        #region IDateHelper Members
        /// <summary>
        /// Returns now.
        /// </summary>
        /// <returns>
        /// </returns>
        public DateTime Now
        {
            get
            {
                return DateTime.Now;
            }
        }
        #endregion

        #region Public Methods and Operators
        /// <summary>
        /// Calculate the first day of the current month.
        /// </summary>
        /// <returns>
        /// Datetime.
        /// </returns>
        public DateTime GetFirstDayOfCurrentMonth()
        {
            return new DateTime(DateTime.Now.Year, DateTime.Now.Month, 1);
        }

        /// <summary>
        /// Calculate the first day of the current year.
        /// </summary>
        /// <returns>
        /// Datetime.
        /// </returns>
        public DateTime GetFirstDayOfCurrentYear()
        {
            return new DateTime(DateTime.Now.Year, 1, 1);
        }

        /// <summary>
        /// Calculate the first day of the given year.
        /// </summary>
        /// <param name="year">
        /// Year "yyyy".
        /// </param>
        /// <returns>
        /// Datetime.
        /// </returns>
        public DateTime GetFirstDayOfCustomYear(int year)
        {
            if (year.ToString().Length == 4 && year > 0)
            {
                return new DateTime(year, 1, 1);
            }
            else
            {
                throw new HttpException("the given year has the wrong format or is negative");
            }
        }

        /// <summary>
        /// Calculate the first day of the last.
        /// </summary>
        /// <returns>
        /// Datetime.
        /// </returns>
        public DateTime GetFirstDayOfLastYear()
        {
            return new DateTime(DateTime.Now.Year - 1, 1, 1);
        }

        /// <summary>
        /// Calculate the last day of the current month.
        /// </summary>
        /// <returns>
        /// Datetime.
        /// </returns>
        public DateTime GetLastDayOfCurrentMonth()
        {
            return new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.DaysInMonth(DateTime.Now.Year, DateTime.Now.Month));
        }

        /// <summary>
        /// Calculate the last day of the current year.
        /// </summary>
        /// <returns>
        /// Datetime.
        /// </returns>
        public DateTime GetLastDayOfCurrentYear()
        {
            return new DateTime(DateTime.Now.Year, 12, DateTime.DaysInMonth(DateTime.Now.Year, 12));
        }

        /// <summary>
        /// Calculate the last day of the given year.
        /// </summary>
        /// <param name="year">
        /// Year "yyyy".
        /// </param>
        /// <returns>
        /// Datetime.
        /// </returns>
        public DateTime GetLastDayOfCustomYear(int year)
        {
            if (year.ToString().Length == 4 && year > 0)
            {
                return new DateTime(year, 12, DateTime.DaysInMonth(year, 12));
            }
            else
            {
                throw new HttpException("the given year has the wrong format or is negative");
            }
        }

        /// <summary>
        /// Calculate the last day of the last year.
        /// </summary>
        /// <returns>
        /// Datetime.
        /// </returns>
        public DateTime GetLastDayOfLastYear()
        {
            return new DateTime(DateTime.Now.Year - 1, 12, DateTime.DaysInMonth(DateTime.Now.Year - 1, 12));
        }
        #endregion
    }
}