﻿#region Copyright © convivo GmbH
// ------------------------------------------------------------------------------------------------------------------------
// <copyright file="FormElementsHelper.cs.cs" company="convivo GmbH">
//    Copyright © 2013 convivo GmbH
// </copyright>
// <creator name="convivo GmbH"/>
// ------------------------------------------------------------------------------------------------------------------------
#endregion

namespace Fruitmonitoring.Helper.Utility
{
    #region usings
    using System;
    using System.Collections.Generic;
    using System.Drawing;
    using System.Linq;
    using System.Text;
    using System.Web.Mvc;
    using System.Web.UI.WebControls;

    using DevExpress.Utils;
    using DevExpress.Web;
    using DevExpress.Web.Mvc;

    using Fruitmonitoring.Helper.Validation;

    using Languages;
    using Languages.Pages.Laboratory.Samples.Samples;

    #endregion

    /// <summary>
    /// The form elements helper.
    /// </summary>
    public class FormElementsHelper
    {
        #region Static Fields
        /// <summary>
        /// The buttonwidth.
        /// </summary>
        public static readonly int BUTTONWIDTH = 130;

        /// <summary>
        /// The defaultfontcolor.
        /// </summary>
        public static readonly Color DEFAULTFONTCOLOR = Color.FromArgb(51, 51, 51); // default font color

        /// <summary>
        /// The formelementwidth.
        /// </summary>
        public static readonly int FORMELEMENTWIDTH = 250;

        /// <summary>
        /// The formname.
        /// </summary>
        public static readonly string FORMNAME = "addDataSetForm";

        /// <summary>
        /// The requestverificationtoken.
        /// </summary>
        public static readonly string REQUESTVERIFICATIONTOKEN = "__RequestVerificationToken";
        #endregion

        #region Public Methods and Operators
        /// <summary>
        /// Determine if the current form is the edit dataset form.
        /// </summary>
        /// <param name="viewData">
        /// Current viewdata object.
        /// </param>
        /// <returns>
        /// True if edit form, otherwise false.
        /// </returns>
        public static bool IsEditForm(ViewDataDictionary viewData)
        {
            return false;
        }

        /// <summary>
        /// Set the default settings to an CheckBoxList.
        /// </summary>
        /// <param name="settings">
        /// CheckBoxList settings object which should be manipulated.
        /// </param>
        /// <param name="name">
        /// Name of the checkboxlist (unique).
        /// </param>
        /// <param name="textField">
        /// Model member which holds the textfield value (visible text in the combobox).
        /// </param>
        /// <param name="valueField">
        /// Model member which holds the value (usually an retialerCompanyId).
        /// </param>
        /// <param name="showCompleteErrorMessage">
        /// True: error message is shown with icon an text. Otherwise with icon and tooltip.
        /// </param>
        public static void LoadDefaultCheckBoxListSettings(
            ref CheckBoxListSettings settings,
            string name,
            string textField,
            string valueField,
            bool showCompleteErrorMessage = true)
        {
            ;
        }

        /// <summary>
        /// Set the default settings to an checkbox.
        /// </summary>
        /// <param name="settings">
        /// Checkbox settings object which should be manipulated.
        /// </param>
        /// <param name="showCompleteErrorMessage">
        /// True: error message is shown with icon an text. Otherwise with icon and tooltip.
        /// </param>
        public static void LoadDefaultCheckBoxSettings(ref CheckBoxSettings settings, bool showCompleteErrorMessage = true)
        {
            ;
        }

        /// <summary>
        /// Set the default settings to an combobox.
        /// </summary>
        /// <param name="settings">
        /// Combobox settings object which should be manipulated.
        /// </param>
        /// <param name="textField">
        /// Model member which holds the textfield value (visible text in the combobox).
        /// </param>
        /// <param name="valueField">
        /// Model member which holds the value (usually an retialerCompanyId).
        /// </param>
        /// <param name="selectFirstItem">
        /// Select first entry, if model is null.
        /// </param>
        /// <param name="showCompleteErrorMessage">
        /// True: error message is shown with icon an text. Otherwise with icon and tooltip.
        /// </param>
        /// <param name="showDeleteButton">
        /// The show Delete Button.
        /// </param>
        public static void LoadDefaultComboBoxSettings(
            ref ComboBoxSettings settings,
            string textField,
            string valueField,
            bool selectFirstItem = false,
            bool showCompleteErrorMessage = true,
            bool showDeleteButton = true)
        {
            
        }

        /// <summary>
        /// Set the default settings to an dateedit.
        /// </summary>
        /// <param name="settings">
        /// Dateedit settings object which should be manipulated.
        /// </param>
        /// <param name="showCompleteErrorMessage">
        /// True: error message is shown with icon an text. Otherwise with icon and tooltip.
        /// </param>
        /// <param name="isReadOnly">
        /// The is Read Only.
        /// </param>
        public static void LoadDefaultDateEditSettings(ref DateEditSettings settings, bool showCompleteErrorMessage = true, bool isReadOnly = false)
        {
            
        }

        /// <summary>
        /// Set the default settings to an dropdownedit.
        /// </summary>
        /// <param name="settings">
        /// Dropdownedit settings object which should be manipulated.
        /// </param>
        /// <param name="showCompleteErrorMessage">
        /// True: error message is shown with icon an text. Otherwise with icon and tooltip.
        /// </param>
        public static void LoadDefaultDropDownEditSettings(ref DropDownEditSettings settings, bool showCompleteErrorMessage = true)
        {
            
        }

        /// <summary>
        /// Set the default settings to an label.
        /// </summary>
        /// <param name="settings">
        /// Textbox settings object which should be manipulated.
        /// </param>
        /// <param name="text">
        /// The text.
        /// </param>
        /// <param name="viewData">
        /// The view Data.
        /// </param>
        public static void LoadDefaultLabelSettings(ref LabelSettings settings, string text, ViewDataDictionary viewData)
        {
            
        }

        /// <summary>
        /// Set the default settings to an checkbox.
        /// </summary>
        /// <param name="settings">
        /// Checkbox settings object which should be manipulated.
        /// </param>
        /// <param name="showCompleteErrorMessage">
        /// True: error message is shown with icon an text. Otherwise with icon and tooltip.
        /// </param>
        public static void LoadDefaultMemoSettings(ref MemoSettings settings, bool showCompleteErrorMessage = true)
        {
            
        }

        /// <summary>
        /// Set the default settings to an RadioButtonList.
        /// </summary>
        /// <param name="settings">
        /// RadioButtonList settings object which should be manipulated.
        /// </param>
        /// <param name="textField">
        /// Model member which holds the textfield value (visible text in the combobox).
        /// </param>
        /// <param name="valueField">
        /// Model member which holds the value (usually an retialerCompanyId).
        /// </param>
        /// <param name="selectDefaultIfNull">
        /// Select the 0 index if model is null.
        /// </param>
        /// <param name="showCompleteErrorMessage">
        /// True: error message is shown with icon an text. Otherwise with icon and tooltip.
        /// </param>
        public static void LoadDefaultRadioButtonListSettings(
            ref RadioButtonListSettings settings,
            string textField,
            string valueField,
            bool selectDefaultIfNull = true,
            bool showCompleteErrorMessage = true)
        {
            
        }

        /// <summary>
        /// Set the default settings to an RadioButtonList to show additional textboxes on selection
        /// hint: "_sampleFormJSPartial.cshtml" must be included.
        /// </summary>
        /// <param name="settings">
        /// RadioButtonList settings object which should be manipulated.
        /// </param>
        /// <param name="componentName">
        /// Radiobuttonlist name.
        /// </param>
        /// <param name="container">
        /// List which holds all div ids that should be shown on radio-button-list selection.
        /// </param>
        /// <param name="ids">
        /// List of the single radio button ids, where the textbox should append to if the radiobutton is selected.
        /// </param>
        public static void LoadDefaultRadioButtonListSettings_DisplayAdditionalTextbox(
            ref RadioButtonListSettings settings,
            string componentName,
            List<string> container,
            List<Guid> ids)
        {
            
        }

        /// <summary>
        /// Set the default settings to an SpinEdit (for GLN spinedit).
        /// </summary>
        /// <param name="settings">
        /// SpinEdit settings object which should be manipulated.
        /// </param>
        /// <param name="viewData">
        /// Current viewdata object.
        /// </param>
        /// <param name="showCompleteErrorMessage">
        /// True: error message is shown with icon an text. Otherwise with icon and tooltip.
        /// </param>
        public static void LoadDefaultSpinEditGLNSettings(ref SpinEditSettings settings, ViewDataDictionary viewData, bool showCompleteErrorMessage = true)
        {
            
        }

        /// <summary>
        /// Set the default settings to an SpinEdit.
        /// </summary>
        /// <param name="settings">
        /// SpinEdit settings object which should be manipulated.
        /// </param>
        /// <param name="viewData">
        /// Current viewdata object.
        /// </param>
        /// <param name="showCompleteErrorMessage">
        /// True: error message is shown with icon an text. Otherwise with icon and tooltip.
        /// </param>
        public static void LoadDefaultSpinEditSettings(ref SpinEditSettings settings, ViewDataDictionary viewData, bool showCompleteErrorMessage = true)
        {
            
        }

        /// <summary>
        /// Set the default settings to an text-input-field.
        /// </summary>
        /// <param name="settings">
        /// Textbox settings object which should be manipulated.
        /// </param>
        /// <param name="showCompleteErrorMessage">
        /// True: error message is shown with icon an text. Otherwise with icon and tooltip.
        /// </param>
        public static void LoadDefaultTextBoxSettings(ref TextBoxSettings settings, bool showCompleteErrorMessage = true)
        {
            
        }

        /// <summary>
        /// Set an editor to readonly (DevExpress).
        /// </summary>
        /// <param name="settings">The editor settings.</param>
        public static void SetReadonly(EditorSettings settings)
        {
            
        }
        #endregion
    }
}