﻿#region Copyright © convivo GmbH
// ------------------------------------------------------------------------------------------------------------------------
// <copyright file="GridViewHelper.cs.cs" company="convivo GmbH">
//    Copyright © 2013 convivo GmbH
// </copyright>
// <creator name="convivo GmbH"/>
// ------------------------------------------------------------------------------------------------------------------------
#endregion

namespace Fruitmonitoring.Helper.Utility
{
#region usings
    using System;
    using System.Collections.Generic;
    using System.Diagnostics.CodeAnalysis;
    using System.Drawing;
    using System.Globalization;
    using System.Linq;
    using System.Text.RegularExpressions;
    using System.Web;
    using System.Web.Mvc;
    using System.Web.UI;
    using System.Web.UI.WebControls;
    using DevExpress.Utils;
    using DevExpress.Web;
    using DevExpress.Web.Mvc;
    using DevExpress.Web.Mvc.UI;
    using Fruitmonitoring.Infrastructure.Security;
    using Fruitmonitoring.Models.ComboBox;
    using Languages;
    using Languages.Components;
    using Languages.ModelData.SampleResult;
    using log4net;

    #endregion

    /// <summary>
    ///     this class provides some helper functions for the devexpress gridview
    /// </summary>
    public class GridViewHelper
    {
        #region gridview names
        /// <summary>
        /// </summary>
        public static readonly string DASHBOARDOVERVIEWADMINGRIDVIEWID = "gridview_admin_dashboard_overview";

        /// <summary>
        /// </summary>
        public static readonly string DASHBOARDPERIODADMINGRIDVIEWID = "gridview_admin_dashboard_period";

        /// <summary>
        /// </summary>
        public static readonly string DASHBOARDLABBUDGETADMINGRIDVIEWID = "gridview_admin_dashboard_lab_budget";

        /// <summary>
        /// </summary>
        public static readonly string WEIGHTUNITADMINGRIDVIEWID = "gridview_admin_weightunit";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLEADMINGRIDVIEWID = "gridview_admin_sample";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLEANONYMOUSADMINGRIDVIEWID = "gridview_admin_sampleanonymous";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERGROUPADMINGRIDVIEWID = "gridview_admin_parametergroup";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERINGREDIENTSGRIDVIEWID = "gridview_admin_parameteringredients";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERADMINGRIDVIEWID = "gridview_admin_parameter";

        /// <summary>
        /// </summary>
        public static readonly string COMPANYADMINGRIDVIEWID = "gridview_admin_company";

        /// <summary>
        /// </summary>
        public static readonly string RETAILERTOSUPPLIERADMINGRIDVIEWID = "gridview_admin_retailertosupplier";

        /// <summary>
        /// </summary>
        public static readonly string SUPPLIERINFORMATIONSADMINGRIDVIEWID = "gridview_admin_supplierinformations";

        /// <summary>
        /// </summary>
        public static readonly string EVALUATIONBASISADMINGRIDVIEWID = "gridview_admin_evaluationbasis";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTADMINGRIDVIEWID = "gridview_admin_product";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTGROUPADMINGRIDVIEWID = "gridview_admin_productgroup";

        /// <summary>
        /// </summary>
        public static readonly string PROCESSINGSTATUSADMINGRIDVIEWID = "gridview_admin_processingstatus";

        /// <summary>
        /// </summary>
        public static readonly string INTENDEDUSEADMINGRIDVIEWID = "gridview_admin_intendeduse";

        /// <summary>
        /// </summary>
        public static readonly string COUNTRYADMINGRIDVIEWID = "gridview_admin_country";

        /// <summary>
        /// </summary>
        public static readonly string PRIVATEBRANDADMINGRIDVIEWID = "gridview_admin_privatebrand";

        /// <summary>
        /// </summary>
        public static readonly string METHODADMINGRIDVIEWID = "gridview_admin_method";

        /// <summary>
        /// </summary>
        public static readonly string MEASUREMENTPRESETTINGADMINGRIDVIEWID = "gridview_admin_measurementpresetting";

        /// <summary>
        /// </summary>
        public static readonly string RATINGSCHEMAADMINGRIDVIEWID = "gridview_admin_ratingschema";

        /// <summary>
        /// </summary>
        public static readonly string RATINGAREAADMINGRIDVIEWID = "gridview_admin_ratingarea";

        /// <summary>
        /// </summary>
        public static readonly string NEWSADMINGRIDVIEWID = "gridview_admin_news";

        /// <summary>
        /// </summary>
        public static readonly string DOCUMENTADMINVIEWID = "gridview_admin_document";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONBUSINESSADMINGRIDVIEWID = "gridview_admin_certificationbusiness";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONPRODUCTADMINGRIDVIEWID = "gridview_admin_certificationproduct";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONQUALITYSEALADMINGRIDVIEWID = "gridview_admin_certificationqualityseal";

        /// <summary>
        /// </summary>
        public static readonly string TRANSLATIONADMINGRIDVIEWID = "gridview_admin_translation";

        /// <summary>
        /// </summary>
        public static readonly string ACCOUNTMANAGERADMINGRIDVIEWID = "gridview_admin_accountmanagement";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLERUSERMANAGERADMINGRIDVIEWID = "gridview_admin_samplermanagement";

        /// <summary>
        /// </summary>
        public static readonly string DASHBOARDOVERVIEWRETAILERGRIDVIEWID = "gridview_retailer_dashboard_overview";

        /// <summary>
        /// </summary>
        public static readonly string DASHBOARDPERIODRETAILERGRIDVIEWID = "gridview_retailer_dashboard_period";

        /// <summary>
        /// </summary>
        public static readonly string WEIGHTUNITRETAILERGRIDVIEWID = "gridview_retailer_weightunit";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLERETAILERGRIDVIEWID = "gridview_retailer_sample";

        /// <summary>
        /// </summary>
        public static readonly string ORDEREDSAMPLESGRIDVIEWID = "gridview_orderer_samples";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLEANONYMOUSRETAILERGRIDVIEWID = "gridview_retailer_sampleanonymous";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERRETAILERGRIDVIEWID = "gridview_retailer_parameter";

        /// <summary>
        /// </summary>
        public static readonly string COMPANYRETAILERGRIDVIEWID = "gridview_retailer_company";

        /// <summary>
        /// </summary>
        public static readonly string SUPPLIERRETAILERGRIDVIEW = "gridview_retailer_supplier_company";

        /// <summary>
        /// </summary>
        public static readonly string EVALUATIONBASISRETAILERGRIDVIEWID = "gridview_retailer_evaluationbasis";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTRETAILERGRIDVIEWID = "gridview_retailer_product";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTGROUPRETAILERGRIDVIEWID = "gridview_retailer_productgroup";

        /// <summary>
        /// </summary>
        public static readonly string COUNTRYRETAILERGRIDVIEWID = "gridview_retailer_country";

        /// <summary>
        /// </summary>
        public static readonly string PRIVATEBRANDRETAILERGRIDVIEWID = "gridview_retailer_privatebrand";

        /// <summary>
        /// </summary>
        public static readonly string RATINGAREARETAILERGRIDVIEWID = "gridview_retailer_ratingarea";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERGROUPRETAILERGRIDVIEWID = "gridview_retailer_parametergroup";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONBUSINESSRETAILERGRIDVIEWID = "gridview_retailer_certificationbusiness";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONPRODUCTRETAILERGRIDVIEWID = "gridview_retailer_certificationproduct";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONQUALITYSEALRETAILERGRIDVIEWID = "gridview_retailer_certificationqualityseal";

        /// <summary>
        /// </summary>
        public static readonly string INTENDEDUSERETAILERGRIDVIEWID = "gridview_retailer_intendeduse";

        /// <summary>
        /// </summary>
        public static readonly string PROCESSINGSTATUSRETAILERGRIDVIEWID = "gridview_retailer_processingstatus";

        /// <summary>
        /// </summary>
        public static readonly string WEIGHTUNITLABORATORYGRIDVIEWID = "gridview_laboratory_weightunit";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERLABORATORYGRIDVIEWID = "gridview_laboratory_parameter";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTLABORATORYGRIDVIEWID = "gridview_laboratory_product";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTGROUPLABORATORYGRIDVIEWID = "gridview_laboratory_productgroup";

        /// <summary>
        /// </summary>
        public static readonly string PROCESSINGSTATUSLABORATORYGRIDVIEWID = "gridview_laboratory_processingstatus";

        /// <summary>
        /// </summary>
        public static readonly string INTENDEDUSELABORATORYGRIDVIEWID = "gridview_laboratory_intendeduse";

        /// <summary>
        /// </summary>
        public static readonly string COUNTRYLABORATORYGRIDVIEWID = "gridview_laboratory_country";

        /// <summary>
        /// </summary>
        public static readonly string PRIVATEBRANDLABORATORYGRIDVIEWID = "gridview_laboratory_privatebrand";

        /// <summary>
        /// </summary>
        public static readonly string RATINGAREALABORATORYGRIDVIEWID = "gridview_laboratory_ratingarea";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONBUSINESSLABORATORYGRIDVIEWID = "gridview_laboratory_certificationbusiness";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONPRODUCTLABORATORYGRIDVIEWID = "gridview_laboratory_certificationproduct";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONQUALITYSEALLABORATORYGRIDVIEWID = "gridview_laboratory_certificationqualityseal";

        /// <summary>
        /// </summary>
        public static readonly string METHODLABORATORYGRIDVIEWID = "gridview_laboratory_method";

        /// <summary>
        /// </summary>
        public static readonly string ACCOUNTMANAGERRETAILERGRIDVIEWID = "gridview_retailer_accountmanagement";

        /// <summary>
        /// </summary>
        public static readonly string REGIONMANAGERRETAILERGRIDVIEWID = "gridview_retailer_regionmanagement";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLELABORATORYGRIDVIEWID = "gridview_laboratory_sample";

        /// <summary>
        /// </summary>
        public static readonly string ACCOUNTMANAGERLABORATORYGRIDVIEWID = "gridview_laboratory_accountmanagement";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERGROUPLABORATORYGRIDVIEWID = "gridview_laboratory_parametergroup";

        /// <summary>
        /// </summary>
        public static readonly string INVESTIGATIONORDEROPENLABORATORYGRIDVIEWID = "gridview_laboratory_investigationorderopen";

        /// <summary>
        /// </summary>
        public static readonly string INVESTIGATIONORDERARCHIVELABORATORYGRIDVIEWID = "gridview_laboratory_investigationorderarchive";

        /// <summary>
        /// </summary>
        public static readonly string DOCUMENTFILEUPLOADERGRIDVIEWID = "gridview_document";

        /// <summary>
        /// </summary>
        public static readonly string COMPANYSELECTIONGRIDVIEWID = "gridview_companyselection";

        /// <summary>
        /// </summary>
        public static readonly string SUPPLIERCOMPANYSELECTIONGRIDVIEWID = "gridview_suppliercompanyselection";

        /// <summary>
        /// </summary>
        public static readonly string FILEUPLOADGRIDVIEWID = "gridview_fileupload";

        /// <summary>
        /// </summary>
        public static readonly string DOCUMENTSGRIDVIEWID = "gridview_documents";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTSELECTIONGRIDVIEWID = "gridview_product";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLERESULTSMANAGEMENTGRIDVIEWID = "gridview_sampleresultsmanagement";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLERATINGMANAGEMENTGRIDVIEWID = "gridview_sampleratingmanagement";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLECOMMENTSMANAGEMENTGRIDVIEWID = "gridview_samplecommentsmanagement";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTSINGLEELEMENTSMANAGEMENTGRIDVIEWID = "gridview_productsingleelementsmanagement";

        /// <summary>
        /// </summary>
        public static readonly string LABORATORYMETHODMANAGEMENTGRIDVIEWID = "gridview_laboratorymethodmanagement";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERLISTDETAILGRIDVIEWID = "gridview_parametergroupdetail";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLERUSERMANAGEMENTGRIDVIEWID = "gridview_samplerusermanagement";

        /// <summary>
        /// </summary>
        public static readonly string INVESTIGATIONORDERCOMMONGRIDVIEWID = "gridview_common_investigationorder";

        /// <summary>
        /// </summary>
        public static readonly string INVESTIGATIONPARAMETERGRIDVIEWID = "gridview_common_investigationparametermanagement";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERSELECTIONGRIDVIEWID = "gridview_parameterselection";

        /// <summary>
        /// </summary>
        public static readonly string INVESTIGATIONORDERARCHIVECOMMONGRIDVIEWID = "gridview_common_investigationorderarchive";
        #endregion

        #region controller names
        /// <summary>
        /// </summary>
        public static readonly string WEIGHTUNITADMINCONTROLLERNAME = "WeightUnitAdmin";

        /// <summary>
        /// </summary>
        public static readonly string COMPANYADMINCONTROLLERNAME = "CompanyAdmin";

        /// <summary>
        /// </summary>
        public static readonly string RETAILERTOSUPPLIERADMINCONTROLLERNAME = "RetailerToSupplierAdmin";

        /// <summary>
        /// </summary>
        public static readonly string SUPPLIERINFORMATIONSADMINCONTROLLERNAME = "SupplierInformationAdmin";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTADMINCONTROLLERNAME = "ProductAdmin";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTGROUPADMINCONTROLLERNAME = "ProductGroupAdmin";

        /// <summary>
        /// </summary>
        public static readonly string PROCESSINGSTATUSADMINCONTROLLERNAME = "ProcessingStatusAdmin";

        /// <summary>
        /// </summary>
        public static readonly string INTENDEDUSEADMINCONTROLLERNAME = "IntendedUseAdmin";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERADMINCONTROLLERNAME = "ParameterAdmin";

        /// <summary>
        /// </summary>
        public static readonly string EVALUATIONBASISADMINCONTROLLERNAME = "EvaluationBasisAdmin";

        /// <summary>
        /// </summary>
        public static readonly string COUNTRYADMINCONTROLLERNAME = "CountryAdmin";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLEADMINCONTROLLERNAME = "SampleAdmin";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLEANONYMOUSADMINCONTROLLERNAME = "SampleAnonymousAdmin";

        /// <summary>
        /// </summary>
        public static readonly string DASHBOARDADMINCONTROLLERNAME = "DashboardAdmin";

        /// <summary>
        /// </summary>
        public static readonly string PRIVATEBRANDADMINCONTROLLERNAME = "PrivateBrandAdmin";

        /// <summary>
        /// </summary>
        public static readonly string METHODADMINCONTROLLERNAME = "MethodAdmin";

        /// <summary>
        /// </summary>
        public static readonly string MEASUREMENTPRESETTINGADMINCONTROLLERNAME = "MeasurementPresettingAdmin";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONBUSINESSADMINCONTROLLERNAME = "CertificationBusinessAdmin";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONPRODUCTADMINCONTROLLERNAME = "CertificationProductAdmin";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONQUALITYADMINCONTROLLERNAME = "CertificationQualitySealAdmin";

        /// <summary>
        /// </summary>
        public static readonly string RATINGSCHEMAADMINCONTROLLERNAME = "RatingSchemaAdmin";

        /// <summary>
        /// </summary>
        public static readonly string RATINGAREAADMINCONTROLLERNAME = "RatingAreaAdmin";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERGROUPADMINCONTROLLERNAME = "ParameterGroupAdmin";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERINGREDIENTSADMINCONTROLLERNAME = "ParameterIngredientsAdmin";

        /// <summary>
        /// </summary>
        public static readonly string ACCOUNTMANAGERADMINCONTROLLERNAME = "AccountManagementAdmin";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLERUSERMANAGERADMINCONTROLLERNAME = "SamplerUserManagementAdmin";

        /// <summary>
        /// </summary>
        public static readonly string NEWSADMINCONTROLLERNAME = "NewsAdmin";

        /// <summary>
        /// </summary>
        public static readonly string DOCUMENTADMINCONTROLLERNAME = "DocumentAdmin";

        /// <summary>
        /// </summary>
        public static readonly string TRANSLATIONADMINCONTROLLERNAME = "TranslationAdmin";

        /// <summary>
        /// </summary>
        public static readonly string WEIGHTUNITRETAILERCONTROLLERNAME = "WeightUnitRetailer";

        /// <summary>
        /// </summary>
        public static readonly string COMPANYRETAILERCONTROLLERNAME = "CompanyRetailer";

        /// <summary>
        /// </summary>
        public static readonly string SUPPLIERRETAILERCONTROLLERNAME = "SupplierRetailer";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTRETAILERCONTROLLERNAME = "ProductRetailer";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTGROUPRETAILERCONTROLLERNAME = "ProductGroupRetailer";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERRETAILERCONTROLLERNAME = "ParameterRetailer";

        /// <summary>
        /// </summary>
        public static readonly string EVALUATIONBASISRETAILERCONTROLLERNAME = "EvaluationBasisRetailer";

        /// <summary>
        /// </summary>
        public static readonly string COUNTRYRETAILERCONTROLLERNAME = "CountryRetailer";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLERETAILERCONTROLLERNAME = "SampleRetailer";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLEANONYMOUSRETAILERCONTROLLERNAME = "SampleAnonymousRetailer";

        /// <summary>
        /// </summary>
        public static readonly string DASHBOARDRETAILERCONTROLLERNAME = "DashboardRetailer";

        /// <summary>
        /// </summary>
        public static readonly string PRIVATEBRANDRETAILERCONTROLLERNAME = "PrivateBrandRetailer";

        /// <summary>
        /// </summary>
        public static readonly string ACCOUNTMANAGERRETAILERCONTROLLERNAME = "AccountManagementRetailer";

        /// <summary>
        /// </summary>
        public static readonly string REGIONMANAGERRETAILERCONTROLLERNAME = "RegionManagementRetailer";

        /// <summary>
        /// </summary>
        public static readonly string COMPANYMANAGERRETAILERCONTROLLERNAME = "CompanyManagementRetailer";

        /// <summary>
        /// </summary>
        public static readonly string RATINGAREARETAILERCONTROLLERNAME = "RatingAreaRetailer";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERGROUPRETAILERCONTROLLERNAME = "ParameterGroupRetailer";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONBUSINESSRETAILERCONTROLLERNAME = "CertificationBusinessRetailer";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONPRODUCTRETAILERCONTROLLERNAME = "CertificationProductRetailer";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONQUALITYRETAILERCONTROLLERNAME = "CertificationQualitySealRetailer";


        /// <summary>
        /// </summary>
        public static readonly string INTENDEDUSERETAILERCONTROLLERNAME = "IntendedUseRetailer";

        /// <summary>
        /// </summary>
        public static readonly string PROCESSINGSTATUSRETAILERCONTROLLERNAME = "ProcessingStatusRetailer";

        /// <summary>
        /// </summary>
        public static readonly string WEIGHTUNITLABORATORYCONTROLLERNAME = "WeightUnitLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTLABORATORYCONTROLLERNAME = "ProductLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTGROUPLABORATORYCONTROLLERNAME = "ProductGroupLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string PROCESSINGSTATUSLABORATORYCONTROLLERNAME = "ProcessingStatusLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string INTENDEDUSELABORATORYCONTROLLERNAME = "IntendedUseLaboratory";


        /// <summary>
        /// </summary>
        public static readonly string PARAMETERLABORATORYCONTROLLERNAME = "ParameterLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string COUNTRYLABORATORYCONTROLLERNAME = "CountryLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string PRIVATEBRANDLABORATORYCONTROLLERNAME = "PrivateBrandLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string RATINGAREALABORATORYCONTROLLERNAME = "RatingAreaLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONBUSINESSLABORATORYCONTROLLERNAME = "CertificationBusinessLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONPRODUCTLABORATORYCONTROLLERNAME = "CertificationProductLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string CERTIFICATIONQUALITYLABORATORYCONTROLLERNAME = "CertificationQualitySealLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string METHODLABORATORYCONTROLLERNAME = "MethodLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string DOCUMENTDOWNLOADLABORATORYCONTROLLER = "DocumentDownloadLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLELABORATORYBASECONTROLLERNAME = "SampleLaboratoryBase";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLELABORATORYALLSAMPLESCONTROLLERNAME = "SampleLaboratoryAllSamples";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLELABORATORYOPENSAMPLESCONTROLLERNAME = "SampleLaboratoryOpenSamples";

        /// <summary>
        /// </summary>
        public static readonly string ACCOUNTMANAGERLABORATORYCONTROLLERNAME = "AccountManagementLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERGROUPLABORATORYCONTROLLERNAME = "ParameterGroupLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string INVESTIGATIONORDEROPENLABORATORYCONTROLLERNAME = "InvestigationOrderOpenLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string INVESTIGATIONORDERARCHIVELABORATORYCONTROLLERNAME = "InvestigationOrderArchiveLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string REGISTERRETAILERLABORATORY = "RegisterRetailerLaboratory";

        /// <summary>
        /// </summary>
        public static readonly string OWNACCOUNTMANAGERCONTROLLERNAME = "OwnAccountManagement";

        /// <summary>
        /// </summary>
        public static readonly string DOCUMENTFILEUPLOADERCONTROLLERNAME = "DocumentFileUploader";

        /// <summary>
        /// </summary>
        public static readonly string COMPANYSELECTIONCONTROLLERNAME = "CompanySelection";

        /// <summary>
        /// </summary>
        public static readonly string SUPPLIERCOMPANYSELECTIONCONTROLLERNAME = "SupplierCompanySelection";

        /// <summary>
        /// </summary>
        public static readonly string COMPANYSEARCHCONTROLLERNAME = "CompanySearch";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLERUSERSEARCHCONTROLLERNAME = "SamplerUserSearch";

        /// <summary>
        /// </summary>
        public static readonly string TRANSLATIONCREATORCONTROLLERNAME = "TranslationExtension";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTSELECTIONCONTROLLERNAME = "ProductSelection";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLERESULTSMANAGEMENTCONTROLLERNAME = "SampleResultsManagement";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLERATINGMANAGEMENTCONTROLLERNAME = "SampleRatingManagement";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLECOMMENTSMANAGEMENTCONTROLLERNAME = "SampleCommentsManagement";

        /// <summary>
        /// </summary>
        public static readonly string PRODUCTSINGLEELEMENTSMANAGEMENTCONTROLLERNAME = "ProductSingleElementsManagement";

        /// <summary>
        /// </summary>
        public static readonly string LABORATORYMETHODMANAGEMENTCONTROLLERNAME = "LaboratoryMethodManagement";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLERUSERMANAGEMENTCONTROLLERNAME = "SamplerUserManagement";

        /// <summary>
        /// </summary>
        public static readonly string PRINTCONTROLLERNAME = "PrintButton";

        /// <summary>
        /// </summary>
        public static readonly string DOWNLOADCONTROLLER = "Download";

        /// <summary>
        /// </summary>
        public static readonly string ADVANCEDSEARCHCONTROLLER = "AdvancedSearch";

        /// <summary>
        /// </summary>
        public static readonly string INVESTIGATIONORDERCOMMONCONTROLLERNAME = "InvestigationOrder";

        /// <summary>
        /// </summary>
        public static readonly string INVESTIGATIONPARAMETERCONTROLLERNAME = "InvestigationParameterManagement";

        /// <summary>
        /// </summary>
        public static readonly string PARAMETERSELECTIONCONTROLLERNAME = "ParameterSelection";

        /// <summary>
        /// </summary>
        public static readonly string INVESTIGATIONORDERARCHIVECOMMONCONTROLLERNAME = "InvestigationOrderArchive";

        public static readonly string ORDEREDSAMPLESCONTROLLERNAME = "OrderedSamples";
        #endregion

        #region custom callback actions
        /// <summary>
        /// </summary>
        public const string CUSTOMCALLBACKACTIONKEY = "CUSTOMCALLBACKACTION";

        /// <summary>
        /// </summary>
        public const string CUSTOMCALLBACKACTIONRESETLAYOUT = "CUSTOMCALLBACKACTIONRESETLAYOUT";

        /// <summary>
        /// </summary>
        public const string CUSTOMCALLBACKACTIONCOMBINEFILTER = "CUSTOMCALLBACKACTIONCOMBINEFILTER";

        /// <summary>
        /// </summary>
        public const string CUSTOMCALLBACKACTIONREMOVEFILTER = "CUSTOMCALLBACKACTIONREMOVEFILTER";
        #endregion

        #region static properties
        /// <summary>
        /// </summary>
        public static readonly string GRIDVIEWCOMPONENTSPATH = "Fruitmonitoring/GridViews/";

        /// <summary>
        /// </summary>
        public static readonly string SAMPLELABORATORYSHAREDVIEWSPATH = "Fruitmonitoring/SampleLaboratoryShared/";

        /// <summary>
        /// </summary>
        public static readonly int COMMANDCOLUMNWIDTHSINGLEBUTTON = 37;

        /// <summary>
        /// </summary>
        public static readonly int COMMANDCOLUMNWIDTHADDITIONALBUTTON = 24;

        /// <summary>
        /// </summary>
        public static readonly int STANDARDCOLUMNWIDTH = 100;

        /// <summary>
        /// </summary>
        public static readonly int STANDARDCOLUMNWIDTHMIN = 30;

        /// <summary>
        /// Width of a column if only one column exists in the gridview.
        /// </summary>
        public static readonly int COLUMNWIDTHSINGLECOLUMN = 700;

        /// <summary>
        /// </summary>
        public static readonly string DEFAULTADDACTION = "Add";

        /// <summary>
        /// </summary>
        public static readonly string DEFAULTEDITACTION = "Edit";

        /// <summary>
        /// </summary>
        public static readonly string DEFAULTDELETEACTION = "Delete";

        /// <summary>
        /// </summary>
        public static readonly string DEFAULTLISTVIEWACTION = "GridViewListView";

        /// <summary>
        /// </summary>
        public static readonly string DEFAULTLISTVIEWINITACTION = "GridViewListViewInit";

        /// <summary>
        /// </summary>
        public static readonly string DEFAULTLISTVIEWADVANCEDSEARCHACTION = "GridViewListViewAdvancedSearch";

        /// <summary>
        /// </summary>
        public static readonly Color COMMANDCOLUMNBACKGROUNDCOLOR = Color.FromArgb(222, 247, 205); // #DEF7CD

        /// <summary>
        /// </summary>
        public static readonly string PATHTOEDITIMAGE = "~/Content/Images/Icons/EditWithBG.png";

        /// <summary>
        /// </summary>
        public static readonly string PATHTODELETEIMAGE = "~/Content/Images/Icons/DeleteWithBG.png";

        /// <summary>
        /// </summary>
        public static readonly string PATHTOERASERIMAGE = "~/Content/Images/Icons/EraserWithBG.png";

        /// <summary>
        /// </summary>
        public static readonly string PATHTODETAILIMAGE = "~/Content/Images/Icons/DetailWithBG.png";

        /// <summary>
        /// </summary>
        public static readonly string EDITBTNID = "GRIDVIEWEDITBTN";

        /// <summary>
        /// </summary>
        public static readonly string DELETEBTNID = "GRIDVIEWDELETEBTN";

        /// <summary>
        /// </summary>
        public static readonly string DETAILBTNID = "GRIDVIEWDETAILBTN";

        /// <summary>
        /// </summary>
        public static readonly string INFOBTNID = "GRIDVIEWINFOBTN";
        #endregion

        #region variables
        /// <summary>
        /// </summary>
        public enum RequestMethod
        {
            /// <summary>
            /// </summary>
            GET,

            /// <summary>
            /// </summary>
            POST
        }

        #endregion

        #region methods
        /// <summary>
        /// load set settings to build the ref value utilization column
        /// </summary>
        /// <param name="column"></param>
        /// <param name="viewContext"></param>
        /// <param name="measuredValue"></param>
        /// <param name="refValue"></param>
        /// <param name="measuredValuePredicateName"></param>
        public static void LoadRefValueUtilizationColumn(
            ref MVCxGridViewColumn column,
            ViewContext viewContext,
            string refValueUtilization)
        {
        }

        /// <summary>
        ///     set default gridview footer settings
        /// </summary>
        /// <param name="settings">
        ///     The current used gridview settings.
        /// </param>
        public static void LoadDefaultFooterSettings(ref GridViewSettings settings)
        {
        }

        /// <summary>
        ///     set column default settings
        ///     use this function to provide correct excel export too
        /// </summary>
        /// <param name="settings">
        ///     settings object, were the settings will append to
        /// </param>
        /// <param name="fieldName">
        ///     column field name
        /// </param>
        /// <param name="caption">
        ///     column caption
        /// </param>
        public static void LoadDefaultColumnSettings(ref MVCxGridViewColumn settings, string fieldName, string caption)
        {
        }

        /// <summary>
        ///     set sort column default settings
        /// </summary>
        /// <param name="settings">
        ///     settings object, were the settings will append to
        /// </param>
        /// <param name="sortColumnName">
        ///     Filed-name of the column that is sorted.
        /// </param>
        public static void LoadDefaultSortColumnSettings(ref MVCxGridViewColumn settings, string sortColumnName)
        {
        }

        /// <summary>
        ///     provide default settings for all gridviews which implements the cutom data binding functionality
        /// </summary>
        /// <param name="settings">
        ///     reference to the current gridview settings object
        /// </param>
        /// <param name="viewData">
        ///     viewdata
        /// </param>
        /// <param name="htmlHelper">
        ///     current html helper object
        /// </param>
        /// <param name="columnCollection">
        ///     column collection which holds all columnNamesArray that should be added to the gridview
        /// </param>
        /// <param name="modelType">
        ///     Type of the model (items) that is added to the gridview.
        /// </param>
        /// <param name="sizeAuto">
        ///     gridviews size is set to 100% and resize automatically
        /// </param>
        /// <param name="reloadOnInit">
        ///     Should the gridview perform a callback on initialize? (needed if the gridview is inintialized with no data content)
        /// </param>
        public static void LoadDefaultCustomBindingSettings(
            ref GridViewSettings settings,
            ViewDataDictionary viewData,
            HtmlHelper htmlHelper,
            MVCxGridViewColumnCollection columnCollection,
            Type modelType,
            bool sizeAuto = true,
            bool reloadOnInit = true)
        {
        }

        /// <summary>
        ///     provide default settings for all gridviews which use the default custom data binding functionality
        /// </summary>
        /// <param name="settings">
        ///     reference to the current gridview settings object
        /// </param>
        /// <param name="viewData">
        ///     viewdata
        /// </param>
        /// <param name="htmlHelper">
        ///     current html helper object
        /// </param>
        /// <param name="columnCollection">
        ///     column collection which holds all columnNamesArray that should be added to the gridview
        /// </param>
        /// <param name="modelType">
        ///     Type of the model (items) that is added to the gridview.
        /// </param>
        /// <param name="sizeAuto">
        ///     gridviews size is set to 100% and resize automatically
        /// </param>
        /// <param name="reloadOnInit">
        ///     Should the gridview perform a callback on initialize? (needed if the gridview is inintialized with no data content)
        /// </param>
        public static void LoadDefaultSettings(
            ref GridViewSettings settings,
            ViewDataDictionary viewData,
            HtmlHelper htmlHelper,
            MVCxGridViewColumnCollection columnCollection,
            Type modelType,
            bool sizeAuto = true,
            bool reloadOnInit = true)
        {
        }

        private void CustomColumnDisplayTextHandler(object sender, ASPxGridViewColumnDisplayTextEventArgs e)
        {
        }

        /// <summary>
        ///     load gridviews client layout from database or save the layout settings
        /// </summary>
        /// <param name="sender">
        /// </param>
        /// <param name="e">
        /// </param>
        /// <param name="accountId">
        ///     current users account id
        /// </param>
        /// <param name="gridViewId">
        ///     gridview id to that the layout params belongs to
        /// </param>
        /// <param name="gridViewUserSettings">
        ///     current user layout settings
        /// </param>
        private void loadClientLayoutEventHandler(object sender, ASPxClientLayoutArgs e, Guid accountId, string gridViewId, string gridViewUserSettings)
        {
        }

        /// <summary>
        ///     Handle on databound.
        ///     Provide modeltype to gridview.
        ///     Is needed if you filter an gridview and the resultlist is null.
        ///     Does not work with custom binding.
        ///     For custom binding use ".Bind(null).BindToCustomData( Model )" in gridview.cshtml.
        ///     If bind(null) is executed, this event is raised.
        /// </summary>
        /// <param name="sender">
        /// </param>
        /// <param name="e">
        /// </param>
        /// <param name="modelType">
        /// </param>
        private void DataBoundEventHandler(object sender, EventArgs e, Type modelType)
        {
        }

        /// <summary>
        ///     set column type depend on models property datatype
        /// </summary>
        /// <param name="column">
        ///     column
        /// </param>
        /// <param name="modelType">
        ///     model that holds the data for the column
        /// </param>
        private static void SetColumnType(MVCxGridViewColumn column, Type modelType)
        {
        }

        /// <summary>
        ///     disable sort and filter for a column if needed. this is not implemented by database
        /// </summary>
        /// <param name="column">
        ///     column name
        /// </param>
        private static void handleColumnSortingAndFiltering(MVCxGridViewColumn column)
        {
        }

        /// <summary>
        ///     provide default gridview settings for gridviews in popup
        /// </summary>
        /// <param name="settings">
        ///     reference to the current gridview settings object
        /// </param>
        public static void LoadDefaultGridViewPopupSettings(ref GridViewSettings settings)
        {
        }

        /// <summary>
        ///     provide default gridview settings for dashboard view
        /// </summary>
        /// <param name="settings">
        ///     reference to the current gridview settings object
        /// </param>
        /// <param name="viewData">
        ///     viewdata
        /// </param>
        /// <param name="action">
        ///     The action which loads the gridview data.
        /// </param>
        public static void LoadDefaultDashboardSettings(ref GridViewSettings settings, ViewDataDictionary viewData, string action = "PeriodListView")
        {
        }

        /// <summary>
        ///     add currentRow selection column to gridview
        /// </summary>
        /// <param name="settings">
        ///     reference to the current gridview settings object
        /// </param>
        /// <param name="singleRowSelection">
        ///     user can only select single or multiple rows
        /// </param>
        public static void AddRowSelectioncolumn(ref GridViewSettings settings, bool singleRowSelection = false)
        {
        }

        /// <summary>
        ///     things to do, before gridview is rendered
        /// </summary>
        /// <param name="sender">
        ///     sender
        /// </param>
        /// <param name="e">
        ///     event args
        /// </param>
        /// <param name="viewData">
        ///     current viewdata dictionary
        /// </param>
        private void PreRenderEventHandler(object sender, EventArgs e, ViewDataDictionary viewData)
        {
        }

        /// <summary>
        ///     adds some custom js properties for the gridview
        /// </summary>
        /// <param name="sender">
        ///     sender
        /// </param>
        /// <param name="e">
        ///     event args
        /// </param>
        /// <param name="reloadOnInit">
        ///     Should the gridview perform a callback on initialize? (needed if the gridview is inintialized with no data content)
        /// </param>
        private void CustomJSPropertiesEventHandler(object sender, ASPxGridViewClientJSPropertiesEventArgs e, bool reloadOnInit)
        {
        }

        /// <summary>
        ///     handle rating column background color settings
        /// </summary>
        /// <param name="sender">
        ///     sender
        /// </param>
        /// <param name="e">
        ///     event args
        /// </param>
        public void HtmlDataCellPreparedEventHandler(object sender, ASPxGridViewTableDataCellEventArgs e)
        {
        }

        /// <summary>
        ///     set the default settings for the command-column-buttons  ( inline edit form )
        ///     Important: the following properties must be set in the gridview!
        ///     settings.SettingsEditing.AddNewRowRouteValues
        ///     settings.SettingsEditing.UpdateRowRouteValues
        ///     settings.SettingsEditing.DeleteRowRouteValues
        /// </summary>
        /// <param name="settings">
        ///     reference to the current gridview settings object
        /// </param>
        /// <param name="html">
        /// </param>
        /// <param name="showNew">
        ///     should the new button rendered
        /// </param>
        /// <param name="showNewInHeader">
        ///     should the new button rendered in the column header instead of each currentRow
        /// </param>
        /// <param name="showEdit">
        ///     should the edit button rendered
        /// </param>
        /// <param name="showDelete">
        ///     should the delete button rendered
        /// </param>
        /// <param name="headerText">
        ///     text that is shown in popup header
        /// </param>
        /// <param name="popupContentContainerName">
        ///     edit form popup name
        /// </param>
        public static void LoadDefaultGridViewCommandButtonsSettings(
            ref GridViewSettings settings,
            HtmlHelper html,
            bool showNew,
            bool showNewInHeader,
            bool showEdit,
            bool showDelete,
            string headerText,
            string popupContentContainerName)
        {
        }

        /// <summary>
        ///     Set default settings for the gridviews in sample detail view
        /// </summary>
        /// <param name="settings">
        /// </param>
        /// <param name="columnCollection">
        /// </param>
        /// <param name="modelType">
        /// </param>
        /// <param name="hasDetailButtons">
        /// </param>
        public static void LoadDefaultGridViewSampleDetailsSettings(
            ref GridViewSettings settings,
            MVCxGridViewColumnCollection columnCollection,
            Type modelType,
            bool hasDetailButtons = false)
        {
        }

        /// <summary>
        ///     get the edit dataset button which can be added to the gridview command column gridview
        /// </summary>
        /// <param name="viewData">
        ///     viewdata object
        /// </param>
        /// <param name="actionUrl">
        ///     action url
        /// </param>
        /// <param name="popupHeaderText">
        ///     the popups header text
        /// </param>
        /// <param name="showAdditionalContentInPopup">
        /// </param>
        /// <param name="showDefaultSubmitButton">
        /// </param>
        /// <param name="forceShowButton">
        ///     show edit button even it is no admin
        /// </param>
        /// <returns>
        /// </returns>
        public static GridViewCustomButton GetEditButton(
            ViewDataDictionary viewData,
            string actionUrl,
            string popupHeaderText,
            bool showAdditionalContentInPopup = false,
            bool showDefaultSubmitButton = true,
            bool forceShowButton = false)
        {
            return null;
        }

        /// <summary>
        ///     get the delete dataset button which can be added to the gridview command column gridview
        /// </summary>
        /// <param name="viewData">
        ///     viewdata object
        /// </param>
        /// <param name="actionUrl">
        ///     action url
        /// </param>
        /// <returns>
        ///     custom command button object
        /// </returns>
        public static GridViewCustomButton GetDeleteButton(ViewDataDictionary viewData, string actionUrl)
        {
            return null;
        }

        /// <summary>
        ///     Create and adds CommandButtons to a gridView
        /// </summary>
        /// <param name="settings">
        ///     GridViewSettings
        /// </param>
        /// <param name="viewData">
        ///     viewdata
        /// </param>
        /// <param name="buttons">
        ///     List of button definitions
        /// </param>
        public static void AddCommandButtons(
            ref GridViewSettings settings,
            ViewDataDictionary viewData,
            List<GridViewCustomButton> buttons)
        {
        }

        /// <summary>
        ///     calc command column width
        /// </summary>
        /// <param name="settings">
        ///     gridview settings object
        /// </param>
        /// <returns>
        ///     calculated width
        /// </returns>
        private static int calcCommandColumnWidth(ref GridViewSettings settings)
        {
            return 0;
        }

        /// <summary>
        ///     things to do, if delete button is rendered
        ///     - enable /disable buttons
        /// </summary>
        /// <param name="s">
        /// </param>
        /// <param name="e">
        ///     event args
        /// </param>
        private void CustomDeleteButtonInitializeEventHandler(object s, ASPxGridViewCustomButtonEventArgs e)
        {
        }

        /// <summary>
        /// Enables or disables the delete button.
        /// </summary>
        /// <param name="e">The event args.</param>
        /// <param name="row">The data row.</param>
        /// <param name="gridView">Current gridview.</param>
        private void RestrictDeleteButton(ASPxGridViewCustomButtonEventArgs e, object row, MVCxGridView gridView)
        {
        }

        /// <summary>
        ///     renders two buttons for sorting each element in the gridview
        /// </summary>
        /// <param name="htmlHelper">
        ///     actual html helper object
        /// </param>
        /// <param name="rowid">
        ///     current currentRow retialerCompanyId
        /// </param>
        /// <param name="position">
        ///     index of the rendered buttons as string. will be parsed to int
        /// </param>
        /// <param name="rowCount">
        ///     maximal currentRow count
        /// </param>
        /// <param name="groupId">
        /// </param>
        /// <param name="filter">
        /// </param>
        /// <returns>
        ///     html which defines the two buttons
        /// </returns>
        public static MvcHtmlString RenderSortImages(
            HtmlHelper htmlHelper,
            Guid rowid,
            string position,
            int rowCount,
            Guid? groupId = null,
            string filter = null)
        {
            return null;
        }

        /// <summary>
        ///     renders two buttons for sorting each element in the gridview
        /// </summary>
        /// <param name="htmlHelper">
        ///     actual html helper object
        /// </param>
        /// <param name="rowid">
        ///     current currentRow retialerCompanyId
        /// </param>
        /// <param name="position">
        ///     index of the rendered buttons
        /// </param>
        /// <param name="rowCount">
        ///     maximal currentRow count
        /// </param>
        /// <param name="groupId">
        /// </param>
        /// <param name="filter">
        /// </param>
        /// <returns>
        ///     html which defines the two buttons
        /// </returns>
        public static MvcHtmlString RenderSortImages(
            HtmlHelper htmlHelper,
            Guid rowid,
            int position,
            int rowCount,
            Guid? groupId = null,
            string filter = null)
        {
            return null;
        }

        /// <summary>
        ///     Generates the ja function that should be called if the elements in the gridview are sorted.
        /// </summary>
        /// <param name="rowid">
        ///     The elements id.
        /// </param>
        /// <param name="action">
        ///     Sort "up" or "down".
        /// </param>
        /// <param name="groupId">
        ///     The group id. Is needed if the elements in the gridview belongs to a group.
        /// </param>
        /// <param name="filter">
        ///     A filter value.
        /// </param>
        /// <returns>
        ///     The JS function that can be set on the sort buttons.
        /// </returns>
        [SuppressMessage("StyleCop.CSharp.NamingRules", "SA1305:FieldNamesMustNotUseHungarianNotation", Justification = "Reviewed. Suppression is OK here.")]
        public static string GetJsFunctionCallForSortImages(Guid rowid, string action, Guid? groupId = null, string filter = null)
        {
            return null;
        }

        /// <summary>
        ///     load settings for sample rating column
        ///     filter will be shown as an dropdown
        /// </summary>
        /// <param name="settings">
        ///     sample rating column
        /// </param>
        /// <param name="viewData">
        ///     viewdata container that holds the rating list (key: "Ratings")
        /// </param>
        public static void LoadSampleRatingColumnSettings(ref MVCxGridViewColumn settings, ViewDataDictionary viewData)
        {
        }

        /// <summary>
        ///     Load settings to build the ref value column.
        /// </summary>
        /// <param name="column">
        /// </param>
        /// <param name="viewContext">
        /// </param>
        /// <param name="fieldName">
        /// </param>
        /// <param name="caption">
        /// </param>
        public static void LoadRefValueColumn(ref MVCxGridViewColumn column, ViewContext viewContext, string fieldName, string caption)
        {
        }

        /// <summary>
        ///     Loads settings to fill the MeasuredValueAndPredicate column.
        /// </summary>
        /// <param name="column">
        /// </param>
        /// <param name="viewContext">
        /// </param>
        /// <param name="measuredValueFieldName">
        /// </param>
        /// <param name="predicateValueFieldName">
        /// </param>
        /// <param name="caption">
        /// </param>
        public static void LoadMeasuredValueAndPredicateColumn(
            ref MVCxGridViewColumn column,
            ViewContext viewContext,
            string measuredValueFieldName,
            string predicateValueFieldName,
            string caption)
        {
        }

        /// <summary>
        ///     Loads settings to show a decimal column without zeros at the end
        /// </summary>
        /// <param name="column">
        /// </param>
        /// <param name="viewContext">
        /// </param>
        /// <param name="fieldName">
        /// </param>
        /// <param name="caption">
        /// </param>
        /// <param name="decimals">
        /// Fix number of decimal places to show.
        /// </param>
        public static void LoadDecimalColumnSettings(ref MVCxGridViewColumn column, ViewContext viewContext, string fieldName, string caption, int decimals = -1)
        {
        }
        #endregion
    }
}