﻿#region Copyright © convivo GmbH
// ------------------------------------------------------------------------------------------------------------------------
// <copyright file="AdminEmailer.cs.cs" company="convivo GmbH">
//    Copyright © 2014 convivo GmbH
// </copyright>
// <creator name="convivo GmbH"/>
// ------------------------------------------------------------------------------------------------------------------------
#endregion

namespace Fruitmonitoring.Helper.Utility.Tasks.SampleOverdueTask
{
    #region usings
    using System.Configuration;

    using Fruitmonitoring.Helper.Utility.Email;
    using Fruitmonitoring.Models;

    using log4net;

    #endregion

    /// <summary>
    /// Laborergebnis emails are accounted for and
    /// summary email is sent to administration.
    /// </summary>
    public class AdminEmailer
    {
        #region Properties
        /// <summary>
        /// Gets or sets the admin mail.
        /// </summary>
        public int AdminMail { get; set; }

        /// <summary>
        /// Gets or sets the lab mail success.
        /// </summary>
        public int LabMailSuccess { get; set; }

        /// <summary>
        /// Gets or sets the lab mail total.
        /// </summary>
        public int LabMailTotal { get; set; }

        /// <summary>
        /// Gets or sets the notification content.
        /// </summary>
        public string notificationContent { get; set; }

        /// <summary>
        /// Gets or sets the retailer mail success.
        /// </summary>
        public int RetailerMailSuccess { get; set; }

        /// <summary>
        /// Gets or sets the retailer mail total.
        /// </summary>
        public int RetailerMailTotal { get; set; }

        /// <summary>
        /// Gets or sets the task name.
        /// </summary>
        public string TaskName { get; set; }
        #endregion

        #region Methods
        /// <summary>
        /// Summary mail sent to convivo Admin.
        /// </summary>
        /// <param name="db">
        /// </param>
        /// <param name="examinationType">
        /// A user readable string for the examination type.
        /// </param>
        /// <param name="errorLog">
        /// The error Log.
        /// </param>
        internal void sendNotificationMail(Entities db, string examinationType, ILog errorLog)
        {
            setNotificationContent(examinationType);
            var emailer = new Emailer();
            var eMailOptions =
                new EMailOptions(
                    string.Format("FM Daily Task: '{0}/{1}' Email notification for '{2}' examination", getSuccess(), getTotal(), examinationType),
                    ConfigurationManager.AppSettings["ConvivoAdminMailbox"],
                    notificationContent,
                    false,
                    null);
            eMailOptions.Importance = getSuccess() == getTotal() ? EMailOptions.IMPORTANCE.NORMAL : EMailOptions.IMPORTANCE.HIGH;
            eMailOptions.ContentType = EMailOptions.CONTENTTYPE.TEXT;

            var result = emailer.SendMail(eMailOptions, errorLog);
        }

        /// <summary>
        /// Sum of all email successfully sent out.
        /// </summary>
        /// <returns>
        /// The <see cref="int"/>.
        /// </returns>
        private int getSuccess()
        {
            return AdminMail + RetailerMailSuccess + LabMailSuccess;
        }

        /// <summary>
        /// Sum of all emails to send out.
        /// </summary>
        /// <returns>
        /// The <see cref="int"/>.
        /// </returns>
        private int getTotal()
        {
            return 1 + RetailerMailTotal + LabMailTotal;
        }

        /// <summary>
        /// Message content for convivo admin email.
        /// </summary>
        /// <param name="examinationType">
        /// The examination Type.
        /// </param>
        private void setNotificationContent(string examinationType)
        {
            notificationContent = string.Format(
                "Notification: A total of '{0}' from '{1}' emails were successfully sent out for overdue '{2}' sample results.",
                getSuccess(),
                getTotal(),
                examinationType);
        }
        #endregion
    }
}