﻿#region Copyright © convivo GmbH
// ------------------------------------------------------------------------------------------------------------------------
// <copyright file="DateMaxTodayAttribute.cs.cs" company="convivo GmbH">
//    Copyright © 2014 convivo GmbH
// </copyright>
// <creator name="convivo GmbH"/>
// ------------------------------------------------------------------------------------------------------------------------
#endregion

namespace Fruitmonitoring.Helper.Validation
{
    #region usings
    using System;
    using System.ComponentModel.DataAnnotations;
    using System.Globalization;

    #endregion

    /// <summary>
    /// Date is valid, if it is "now" or in the past.
    /// </summary>
    public class DateMaxTodayAttribute : ValidationAttribute
    {
        #region Public Methods and Operators
        /// <summary>
        /// Custom error message format.
        /// </summary>
        /// <param name="name">
        /// The name.
        /// </param>
        /// <returns>
        /// Formatted error message.
        /// </returns>
        public override string FormatErrorMessage(string name)
        {
            return null;
        }
        #endregion

        #region Methods
        /// <summary>
        /// Validate that the given date is not in the future.
        /// </summary>
        /// <param name="value">
        /// Current validated value.
        /// </param>
        /// <param name="validationContext">
        /// Validation context.
        /// </param>
        /// <returns>
        /// Null if validation succeed, otherwise an Validation Result.
        /// </returns>
        protected override ValidationResult IsValid(object value, ValidationContext validationContext)
        {
            try
            {
                if (value != null)
                {
                    var date = (DateTime)value;

                    if (DateTime.Compare(date, DateTime.Now) > 0)
                    {
                        // given date is greater than date-now
                        return new ValidationResult(FormatErrorMessage(validationContext.DisplayName));
                    }
                }

                return null;
            }
            catch (Exception)
            {
                return new ValidationResult(FormatErrorMessage(validationContext.DisplayName));
            }
        }
        #endregion
    }
}