﻿#region Copyright © convivo GmbH

// ------------------------------------------------------------------------------------------------------------------------
// <copyright file="ValidationHelper.cs.cs" company="convivo GmbH">
//    Copyright © 2013 convivo GmbH
// </copyright>
// <creator name="convivo GmbH"/>
// ------------------------------------------------------------------------------------------------------------------------

#endregion Copyright © convivo GmbH

namespace Fruitmonitoring.Helper.Validation
{
    #region usings

    using System;
    using System.ComponentModel.DataAnnotations;
    using System.Linq;
    using System.Text.RegularExpressions;

    #endregion usings

    /// <summary>
    /// The validation helper.
    /// </summary>
    public class ValidationHelper
    {
        #region Constants

        /// <summary>
        /// The classificationregex.
        /// </summary>
        public const string CLASSIFICATIONREGEX = @"^[-ABC]{1}$"; // @"^[A-C]{1}|-$";

        // better coverage in comparision to dataAnnotation EmailAddress
        /// <summary>
        /// The emailregex.
        /// </summary>
        public const string EMAILREGEX = @"^[^@\n\r;]+@[^@\n\r;]+\.[A-Za-z0-9]{2,63}$";

        /// <summary>
        /// The fieldlengthlong.
        /// </summary>
        public const ushort FIELDLENGTHLONG = 4000;

        /// <summary>
        /// The fieldlengthshort.
        /// </summary>
        public const ushort FIELDLENGTHSHORT = 255;

        /// <summary>
        /// The ggnregex.
        /// </summary>
        public const string GGNREGEX = @"^\d{13}$";

        /// <summary>
        /// The glnmaxcharacters.
        /// </summary>
        public const ushort GLNMAXCHARACTERS = 13;

        /// <summary>
        /// The glnregex.
        /// </summary>
        public const string GLNREGEX = @"^\d{13}$";

        /// <summary>
        /// The guidregex.
        /// </summary>
        public const string GUIDREGEX = @"\b[A-Fa-f0-9]{8}(?:-[A-Fa-f0-9]{4}){3}-[A-Fa-f0-9]{12}\b";

        /// <summary>
        /// The massemailregex.
        /// </summary>
        public const string MASSEMAILREGEX = @"^([^@\n\r\;]+@[^@\n\r\;]+\.[A-Za-z0-9]{2,63}(\s*;\s*|\s*$))+";

        /// <summary>
        /// The minpasswordlength.
        /// </summary>
        public const ushort MINPASSWORDLENGTH = 8;

        /// <summary>
        /// The minusernamelength.
        /// </summary>
        public const ushort MINUSERNAMELENGTH = 3;

        /// <summary>
        /// The onlyuppercase.
        /// </summary>
        public const string ONLYUPPERCASE = "^[A-Z]+$";

        /// <summary>
        /// The passwordregex.
        /// </summary>
        public const string PASSWORDREGEX = @"^(?=.*[a-zA-Z])(?=.*\d)(?=.*[^\da-zA-Z]).{8,15}$";

        /// <summary>
        /// The refvalue.
        /// </summary>
        public const string REFVALUE = @"^(\d{0,9}([.,]{0,1}\d{1,4}){0,1}){0,1}$";

        /// <summary>
        /// The refvaluemax.
        /// </summary>
        public const decimal REFVALUEMAX = 100000000;

        /// <summary>
        /// Regular expression for validating the measured value.
        /// </summary>
        public const string MEASUREDVALUE = @"^\d{1,15}((,|\.)\d{1,4})?$";

        /// <summary>
        /// This value can be added to required values in forms.
        /// </summary>
        public const string REQUIRED = " *";

        #endregion Constants

        #region Public Methods and Operators

        /// <summary>
        /// Check if a given string is a validEmailAddress.
        /// </summary>
        /// <param name="emailAdress">
        /// Email adress.
        /// </param>
        /// <returns>
        /// True if emailadress is valid.
        /// </returns>
        public static bool ValidateEmail(string emailAdress)
        {
            return false;
        }

        /// <summary>
        /// Get the range attribute for an property from the validation.
        /// </summary>
        /// <param name="modelType">
        /// Model type.
        /// </param>
        /// <param name="propertyname">
        /// Property name in the model.
        /// </param>
        /// <returns>
        /// The rangeAttribute.
        /// </returns>
        public RangeAttribute GetRangeAttribute(Type modelType, string propertyname)
        {
            return null;
        }

        /// <summary>
        /// Get the maximum range value that is specified in the Range-Dataannotation.
        /// </summary>
        /// <param name="modelType">
        /// Model type.
        /// </param>
        /// <param name="propertyname">
        /// Property name in the model.
        /// </param>
        /// <returns>
        /// Maximum range value.
        /// </returns>
        public decimal GetRangeAttributeMaxValue(Type modelType, string propertyname)
        {
            return 0;
        }

        /// <summary>
        /// Get the minimum range value that is specified in the Range-Dataannotation.
        /// </summary>
        /// <param name="modelType">
        /// Model type.
        /// </param>
        /// <param name="propertyname">
        /// Property name in the model.
        /// </param>
        /// <returns>
        /// Minimum range value.
        /// </returns>
        public decimal GetRangeAttributeMinValue(Type modelType, string propertyname)
        {
            return 0;
        }

        #endregion Public Methods and Operators
    }
}